@@ -4,7 +4,7 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-our $VERSION = '0.06';
+our $VERSION = '0.09';
 @ISA = qw/Gedcom::Date/;
 
 use Gedcom::Date;
@@ -178,9 +178,9 @@ sub _date_as_text {
     $dt->set(locale => $locale);
 
     if ($self->{known}{d}) {
-        my $format = $dt->locale->long_date_format;
+        my $format = $dt->locale->date_format_long;
         $format =~ s/%y\b/%Y/g; # never, EVER, use 2-digit years
-        return $dt->strftime($format);
+        return $dt->format_cldr($format);
     } elsif ($self->{known}{m}) {
         return $dt->strftime('%B %Y');
     } else {
@@ -232,6 +232,16 @@ Parse dates from Gedcom files.
 
 Eugene van der Pijll <pijll@gmx.net>
 
+=head1 REPOSITORY
+
+L<https://github.com/ronsavage/Gedcom-Date>.
+
+=head1 See Also
+
+L<Genealogy::Date>.
+
+L<Genealogy::Gedcom::Date>.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2003 Eugene van der Pijll.  All rights reserved.
@@ -242,11 +252,4 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-
-=head1 SEE ALSO
-
-L<Gedcom::Date>,
-
-perl(1).
-
 =cut
